# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
Jul 17 2013 | A135733 [PDF] [DOC] | P. v. Ford 7/17/13 CA1/3 Case Details
Jul 11 2013 | A135094 [PDF] [DOC] | Latinos Unidos etc. v. County of Napa 7/11/13 CA1/3 Case Details
Jul 11 2013 | A135254 [PDF] [DOC] | In re D.B. 7/11/13 CA1/4 Case Details
Jul 10 2013 | A136436 [PDF] [DOC] | In re A.M. 6/19/13 CA1/1 Case Details
Jul 08 2013 | A135214 [PDF] [DOC] | In re J.S. 7/8/13 CA1/2 Case Details
Jun 25 2013 | A135745 [PDF] [DOC] | Neighbors etc. v. City & Cty. of S.F. 5/31/13 CA1/3 Case Details
Jun 24 2013 | A132979M [PDF] [DOC] | Estate of Ben Ali 6/24/13 CA1/1 Case Details
Jun 19 2013 | A135338 [PDF] [DOC] | Smith v. St. Jude Medical 5/21/13 CA1/5 Case Details
Jun 18 2013 | A133591 [PDF] [DOC] | P. v. Nguyen 6/18/13 CA1/1 Case Details
Jun 18 2013 | A134400M [PDF] [DOC] | In re Martinez 6/18/13 CA1/2 Case Details
Jun 14 2013 | A135832 [PDF] [DOC] | Series AGI West Linn v. Eves 6/14/13 CA1/2 Case Details
Jun 11 2013 | A133750 [PDF] [DOC] | J.R. Marketing v. Hartford Casualty 5/17/13 CA1/3 Case Details
Jun 11 2013 | A135131 [PDF] [DOC] | P. v. Barnes 6/11/13 CA1/2 Case Details
Jun 10 2013 | A130955 [PDF] [DOC] | Julius Castle Restaurant v. Payne 6/10/13 CA1/1 Case Details
Jun 03 2013 | A132555 [PDF] [DOC] | Brisbane Lodging v. Webcor Builders 6/3/13 CA1/4 Case Details
May 31 2013 | A134400 [PDF] [DOC] | In re Martinez 5/31/13 CA1/2 Case Details
May 30 2013 | A135290 [PDF] [DOC] | Sims v. Dept. Corrections & Rehabilitation 5/30/13 CA1/2 Case Details
May 29 2013 | A130447 [PDF] [DOC] | AREI II Cases 5/29/13 CA1/3 Case Details
May 29 2013 | A136093 [PDF] [DOC] | Maynard v. BTI Group 5/29/13 CA1/3 Case Details
May 29 2013 | A132979 [PDF] [DOC] | Estate of Ben-Ali 5/29/13 CA1/1 Case Details
May 28 2013 | A135760 [PDF] [DOC] | P. v. Smith 5/7/13 CA1/5 Case Details
May 21 2013 | A133821 [PDF] [DOC] | North Coast Rivers Alliance v. Marin Mun. Water Dist. etc. 5/21/13 CA1/4 Case Details
May 21 2013 | A134706 [PDF] [DOC] | Schwartz v. Provident Life etc. 5/21/13 CA1/3 Case Details
May 16 2013 | A135963 [PDF] [DOC] | Corrie v. Soloway 5/16/13 CA1/1 Case Details
May 13 2013 | A135252 [PDF] [DOC] | P. v. Flores 5/13/13 CA1/4 Case Details
May 09 2013 | A130874 [PDF] [DOC] | Lockaway Storage v. Co. of Alameda 5/9/13 CA1/3 Case Details
Apr 26 2013 | A133045 [PDF] [DOC] | Hall v. Aurora Loan Services 4/26/13 CA1/4 Case Details
Apr 26 2013 | A136240 [PDF] [DOC] | In re Nelson B. 4/26/13 CA1/1 Case Details
Apr 25 2013 | A135274 [PDF] [DOC] | Heritage Pacific v. Monroy 3/29/13 CA1/2 Case Details
Apr 23 2013 | A134829M [PDF] [DOC] | Vasquez v. Greene Motors 4/23/13 CA1/1 Case Details
Apr 18 2013 | A132915 [PDF] [DOC] | P. v. Harrison 4/18/13 CA1/4 Case Details
Apr 18 2013 | A132591 [PDF] [DOC] | In re Stoneroad 4/18/13 CA1/2 Case Details
Apr 16 2013 | A132741M [PDF] [DOC] | Scott v. JPMorgan Chase 4/16/13 CA1/5 Case Details
Apr 15 2013 | A132360 [PDF] [DOC] | P. v. McEvoy 4/15/13 CA1/2 Case Details
Apr 12 2013 | A135593 [PDF] [DOC] | Golden Gate Land Holdings v. East Bay Regional Park 4/12/13 CA1/5 Case Details
Apr 11 2013 | A134290 [PDF] [DOC] | Lister v. Bowen 3/15/13 CA1/2 Case Details
Apr 09 2013 | A134695M [PDF] [DOC] | P. v. Gutierrez 4/9/13 CA1/3 Case Details
Apr 08 2013 | A134089 [PDF] [DOC] | Luttrell v. Island Pacific 4/8/13 CA1/5 Case Details
Apr 02 2013 | A134874 [PDF] [DOC] | In re T.G. 3/6/13 CA1/5 Case Details
Mar 29 2013 | A135898 [PDF] [DOC] | Federal Home Loan Bank v. Countrywide Financial 3/29/13 CA1/5 Case Details
Mar 28 2013 | A131764 [PDF] [DOC] | P. v. Davis 3/28/13 CA1/4 Case Details
Mar 28 2013 | A135790 [PDF] [DOC] | Concerned Dublin Citizens v. City of Dublin 3/7/13 CA1/3 Case Details
Mar 27 2013 | A134829 [PDF] [DOC] | Vasquez v. Greene Motors 3/27/13 CA1/1 Case Details
Mar 22 2013 | A135782 [PDF] [DOC] | Intengan v. BAC Home Loans 3/22/13 CA1/5 Case Details